aboutsummaryrefslogtreecommitdiffstats
path: root/python/tidy/servo_tidy_tests/ban-domrefcell.rs
diff options
context:
space:
mode:
Diffstat (limited to 'python/tidy/servo_tidy_tests/ban-domrefcell.rs')
-rw-r--r--python/tidy/servo_tidy_tests/ban-domrefcell.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/python/tidy/servo_tidy_tests/ban-domrefcell.rs b/python/tidy/servo_tidy_tests/ban-domrefcell.rs
index 6d4e2b2fbc3..74b79e813cf 100644
--- a/python/tidy/servo_tidy_tests/ban-domrefcell.rs
+++ b/python/tidy/servo_tidy_tests/ban-domrefcell.rs
@@ -8,12 +8,12 @@
extern crate script;
use script::test::Dom;
-use script::test::DOMRefCell;
+use script::test::DomRefCell;
use script::test::Node;
struct Foo {
- bar: DOMRefCell<Dom<Node>>
- //~^ ERROR Banned type DOMRefCell<Dom<T>> detected. Use MutDom<T> instead
+ bar: DomRefCell<Dom<Node>>
+ //~^ ERROR Banned type DomRefCell<Dom<T>> detected. Use MutDom<T> instead
}
fn main() {}